Module: Kernel

Defined in:
lib/tebako-runtime.rb

Overview

Some would call it 'monkey patching' but in reality we are adding adapters to gems that shall be aware that they are running in tebako environment

Instance Method Summary collapse

Instance Method Details

#original_requireObject



103
# File 'lib/tebako-runtime.rb', line 103

alias original_require require

#require(name) ⇒ Object



104
105
106
107
108
109
110
# File 'lib/tebako-runtime.rb', line 104

def require(name)
  if ENV["TEBAKO_PASS_THROUGH"]
    TebakoRuntime.process_pass_through name
  else
    TebakoRuntime.process_all name
  end
end