Module: Fiddle
- Defined in:
- lib/tebako-runtime/adapters/fiddle.rb
Overview
Wrapper for Fiddle.dlopen method If the library file to be mapped to is within memfs it is extracted to tmp folder
Class Method Summary collapse
Class Method Details
.dlopen(lib) ⇒ Object
35 36 37 |
# File 'lib/tebako-runtime/adapters/fiddle.rb', line 35 def self.dlopen(lib) dlopen_orig(TebakoRuntime.extract_memfs(lib)) end |